.devcontainer
.dockerignore
.editorconfig
.gitattributes
.gitignore
.hadolint.yaml
.htaccess.dist
.jshintignore
.jshintrc
.markdownlint.json
.markdownlintignore
.stylelintignore
.stylelintrc.json
.typos.toml
AGENTS.md
CHANGELOG.md
CONTRIBUTING.md
CREDITS.md
Docker
LICENSE.txt
Makefile
README.fr.md
README.md
SECURITY.md
app
cli
composer.json
composer.lock
config-user.default.php
config.default.php
constants.php
data
docs
eslint.config.js
extensions
force-https.default.txt
index.html
index.php
lib
opml.default.xml
p
package-lock.json
package.json
phpcs.xml
phpstan-next.neon
phpstan.dist.neon
tests