<?php
return array (
  'environment' => 'production',
  'salt' => '[[salt]]',
  'base_url' => '[[softurl]]/p',
  'auto_update_url' => 'https://update.freshrss.org',
  'language' => 'en',
  'title' => 'FreshRSS',
  'meta_description' => '',
  'logo_html' => '',
  'default_user' => '[[admin_username]]',
  'force_email_validation' => false,
  'allow_anonymous' => false,
  'allow_anonymous_refresh' => false,
  'auth_type' => 'form',
  'reauth_required' => true,
  'reauth_time' => 1200,
  'http_auth_auto_register' => true,
  'http_auth_auto_register_email_field' => '',
  'api_enabled' => false,
  'suppress_csp_warning' => false,
  'csp.frame-ancestors' => '\'none\'',
  'simplepie_syslog_enabled' => true,
  'pubsubhubbub_enabled' => true,
  'allow_robots' => false,
  'allow_referrer' => false,
  'nb_parallel_refresh' => 10,
  'limits' => 
  array (
    'cookie_duration' => 7776000,
    'cache_duration' => 800,
    'cache_duration_min' => 60,
    'cache_duration_max' => 86400,
    'retry_after_default' => 1500,
    'retry_after_max' => 172800,
    'timeout' => 20,
    'max_inactivity' => 9223372036854775807,
    'max_feeds' => 131072,
    'max_categories' => 16384,
    'max_registrations' => 1,
    'max_favicon_upload_size' => 1048576,
  ),
  'curl_options' => 
  array (
  ),
  'db' => 
  array (
    'type' => 'mysql',
    'host' => '[[softdbhost]]',
    'user' => '[[softdbuser]]',
    'password' => '[[softdbpass]]',
    'base' => '[[softdb]]',
    'prefix' => '[[dbprefix]]',
    'connection_uri_params' => '',
    'pdo_options' => 
    array (
    ),
  ),
  'mailer' => 'mail',
  'smtp' => 
  array (
    'hostname' => '',
    'host' => 'localhost',
    'port' => 25,
    'auth' => false,
    'auth_type' => '',
    'username' => '',
    'password' => '',
    'secure' => '',
    'from' => 'root@localhost',
  ),
  'auto_sqlite_export' => 
  array (
    'enabled' => false,
    'retention' => 7,
  ),
  'extensions_enabled' => 
  array (
  ),
  'extensions' => 
  array (
  ),
  'disable_update' => false,
  'trusted_sources' => 
  array (
    0 => '127.0.0.0/8',
    1 => '::1/128',
  ),
);