<?php
return array (
  'enabled' => true,
  'is_admin' => true,
  'language' => '[[language]]',
  'timezone' => '',
  'archiving' => 
  array (
    'keep_period' => 'P3M',
    'keep_max' => 200,
    'keep_min' => 50,
    'keep_favourites' => true,
    'keep_labels' => true,
    'keep_unreads' => false,
  ),
  'ttl_default' => 3600,
  'dynamic_opml_ttl_default' => 43200,
  'mail_login' => '',
  'email_validation_token' => '',
  'token' => '',
  'passwordHash' => '[[admin_pass]]',
  'apiPasswordHash' => '',
  'feverKey' => '',
  'posts_per_page' => 20,
  'since_hours_posts_per_rss' => 168,
  'max_posts_per_rss' => 400,
  'view_mode' => 'normal',
  'default_view' => 'adaptive',
  'default_state' => 2,
  'show_fav_unread' => false,
  'show_title_unread' => true,
  'auto_load_more' => true,
  'display_posts' => false,
  'display_categories' => 'active',
  'show_tags' => 'f',
  'show_tags_max' => 7,
  'show_author_date' => 'h',
  'show_feed_name' => 'a',
  'show_article_icons' => 't',
  'hide_read_feeds' => true,
  'onread_jump_next' => true,
  'lazyload' => true,
  'sides_close_article' => false,
  'sticky_post' => true,
  'reading_confirm' => false,
  'auto_remove_article' => false,
  'mark_updated_article_unread' => false,
  'sort' => 'id',
  'sort_order' => 'DESC',
  'secondary_sort' => 'id',
  'secondary_sort_order' => 'DESC',
  'anon_access' => false,
  'mark_when' => 
  array (
    'article' => true,
    'gone' => false,
    'max_n_unread' => false,
    'reception' => false,
    'same_title_in_feed' => false,
    'scroll' => false,
    'focus' => false,
    'site' => true,
  ),
  'filters' => 
  array (
  ),
  'theme' => 'Origine',
  'darkMode' => 'auto',
  'content_width' => 'thin',
  'shortcuts' => 
  array (
    'actualize' => 'q',
    'mark_read' => 'r',
    'mark_favorite' => 'f',
    'go_website' => 'space',
    'next_entry' => 'j',
    'next_unread_entry' => 'h',
    'prev_entry' => 'k',
    'skip_next_entry' => 'n',
    'skip_prev_entry' => 'p',
    'first_entry' => 'home',
    'last_entry' => 'end',
    'collapse_entry' => 'c',
    'load_more' => 'm',
    'mylabels' => 'l',
    'auto_share' => 's',
    'focus_search' => 'a',
    'user_filter' => 'u',
    'help' => 'f1',
    'close_menus' => 'escape',
    'normal_view' => '1',
    'global_view' => '2',
    'reading_view' => '3',
    'toggle_media' => 'v',
    'toggle_aside' => 't',
  ),
  'show_favicons' => true,
  'icons_as_emojis' => false,
  'simplify_over_n_feeds' => 1000,
  'mark_read_button' => 'big',
  'topline_read' => true,
  'topline_favorite' => true,
  'topline_myLabels' => false,
  'topline_sharing' => false,
  'topline_website' => 'full',
  'topline_thumbnail' => 'none',
  'topline_summary' => false,
  'topline_display_authors' => false,
  'topline_date' => true,
  'topline_link' => true,
  'bottomline_read' => true,
  'bottomline_favorite' => true,
  'bottomline_sharing' => true,
  'bottomline_tags' => true,
  'bottomline_myLabels' => true,
  'bottomline_date' => true,
  'bottomline_link' => true,
  'sharing' => 
  array (
  ),
  'queries' => 
  array (
  ),
  'html5_notif_timeout' => 0,
  'html5_enable_notif' => true,
  'good_notification_timeout' => 3,
  'bad_notification_timeout' => 8,
  'show_nav_buttons' => true,
  'sidebar_hidden_by_default' => false,
  'extensions_enabled' => 
  array (
  ),
  'retrieve_extension_list' => true,
  'send_referrer_allowlist' => 
  array (
  ),
  'extensions' => 
  array (
  ),
);