<?php
 return array (
  'salt' => '[[salt]]',
  'base_url' => '[[softurl]]/p',
  'default_user' => '_',
  'db' => 
  array (
    'type' => 'mysql',
    'host' => '[[softdbhost]]',
    'user' => '[[softdbuser]]',
    'password' => '[[softdbpass]]',
    'base' => '[[softdb]]',
    'prefix' => '[[dbprefix]]',
    'pdo_options' => 
    array (
    ),
  ),
  'pubsubhubbub_enabled' => true,
);
